@@ -1,16 +1,29 @@
 /*
-    This file is part of the kholidays library.
+  This file is part of the kholidays library.
 
-    SPDX-FileCopyrightText: 2014 John Layt <john@layt.net>
+  Copyright 2014 John Layt <john@layt.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Library General Public License for more details.
+
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #ifndef QCALENDARSYSTEM_H
 #define QCALENDARSYSTEM_H
 
-#include <QSharedPointer>
-#include <QDate>
+#include <QtCore/QSharedPointer>
+#include <QtCore/QDate>
 
 class QCalendarSystemPrivate;
 
@@ -73,8 +86,8 @@ public:
     int dayOfWeek(const QDate &date) const;
     int dayOfWeek(int year, int month, int day) const;
 
-    int weekNumber(const QDate &date, int *yearNum = nullptr) const;
-    int weekNumber(int year, int month, int day, int *yearNum = nullptr) const;
+    int weekNumber(const QDate &date, int *yearNum = 0) const;
+    int weekNumber(int year, int month, int day, int *yearNum = 0) const;
 
     int monthsInYear(const QDate &date) const;
     int monthsInYear(int year) const;
